@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12833 2021-04-08 03:09:01Z Casey $
+# $Id: __init__.py 12834 2021-04-08 03:24:09Z Casey $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Casey $ (last)
-# $Date: 2021-04-08 11:09:01 +0800 (Thu, 08 Apr 2021) $
-# $Revision: 12833 $
+# $Date: 2021-04-08 11:24:09 +0800 (週四, 08 四月 2021) $
+# $Revision: 12834 $
 
 from __future__ import print_function
 
@@ -872,7 +872,7 @@ def attachSettings(settingsDict, warns=True, printDetail=True):
                             settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
-                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
+                            settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE'],
                             settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE'],
                             settingsDict['IUNO_MEMBER_ACCOUNT_LOCALE_ENABLE']
                         )
