@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 12658 2020-12-25 01:35:21Z Lavender $
+# $Id: __init__.py 12825 2021-03-31 13:28:58Z Lavender $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $ (last)
-# $Date: 2020-12-25 09:35:21 +0800 (週五, 25 十二月 2020) $
-# $Revision: 12658 $
+# $Date: 2021-03-31 21:28:58 +0800 (週三, 31 三月 2021) $
+# $Revision: 12825 $
 
 # Avoid conflict with Iuno.cloud.logging moudle.
 from __future__ import absolute_import
@@ -27,7 +27,9 @@ import singletonmixin
 
 from Iuppiter.Logging import createLogger
 
-SERVICES = ('queue', 'mail', 'logging', 'browser', 'storage', 'metrics')
+SERVICES = ('queue', 'mail', 'logging', 'browser', 'storage', 'metrics', 'newsletter')
+
+logger = createLogger(__name__)
 
 class LocalCacheProvider(singletonmixin.Singleton):
     """
