@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 12785 2021-02-25 16:33:33Z Lavender $
+# $Id: views.py 12842 2021-04-09 08:30:54Z Lavender $
 #
 # Copyright (c) 2018 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: Lavender $
-# $Date: 2021-02-26 00:33:33 +0800 (週五, 26 二月 2021) $
-# $Revision: 12785 $ 
+# $Date: 2021-04-09 16:30:54 +0800 (週五, 09 四月 2021) $
+# $Revision: 12842 $ 
 
 import json
 import logging
@@ -258,8 +258,11 @@ def placeOrder(self, basket, total,  # noqa (too complex (12))
         order_number=order_number, status=status, request=request, **kwargs)
     
     # send mail
-    msg = "%s: %s" % (_("Order number"), order_number)
-    sendMessageToAdmin(_("Customer order notification"), msg)
+    if request:
+        site = get_current_site(request)
+        msg = "%s: %s" % (_("Order number"), order_number)
+        title = "[%s] %s" % (site.name, _("Customer order notification"))
+        sendMessageToAdmin(str(title), msg)
    
     if user:
         if (user.is_authenticated and 
@@ -1146,8 +1149,8 @@ class SuccessResponseView2(_PaymentDetailsView):
                     data += " %s: %s" % (k, v)
                 msg = "%s: %s\n%s: \n%s" % (
                     _('User'), request.user.username, _("Data"), data)
-                
-                sendMessageToAdmin(_("User checkout notification"), msg)
+                site = get_current_site(request)
+                sendMessageToAdmin("[%s] %s" % (site.name, _("User checkout notification")), msg)
         
         if not self.apiName in [
             SPGATEWAY, ALLPAY, ECPAY, CATHAYBK_CREDIT, 
